#+TITLE: Sacha Chua's Emacs configuration
#+ELEVENTY_COLLECTIONS: _posts
#+ELEVENTY_BASE_DIR: ~/proj/static-blog/
#+ELEVENTY_CATEGORIES+: emacs
#+ELEVENTY_LAYOUT: layouts/post
#+ELEVENTY_BASE_URL: http://sachachua.com
* mastodon.el: Copy toot content as Org Mode             :mastodon:org:emacs:
:PROPERTIES:
:CUSTOM_ID: mastodon-mastodon-el-copy-toot-content-as-org-mode
:EXPORT_DATE: 2025-03-26T12:31:29-0400
:EXPORT_ELEVENTY_PERMALINK: /blog/2025/03/mastodon-el-copy-toot-content-as-org-mode/
:EXPORT_ELEVENTY_FILE_NAME: blog/2025/03/mastodon-el-copy-toot-content-as-org-mode/
:EXPORT_MASTODON: http://social.sachachua.com/@sacha/statuses/01JQ9NF4K6V8MY8S6KCWRYCZS3
:END:

Sometimes I want to copy a toot and include it in
my Org Mode notes, like when I post a thought and
then want to flesh it out into a blog post. This
code defines ~my-mastodon-org-copy-toot-content~,
which converts the toot text to Org Mode format
using Pandoc and puts it in the kill ring so I can
yank it somewhere else.

#+begin_src emacs-lisp
(defun my-mastodon-toot-at-url (&optional url)
	"Return JSON toot object at URL.
If URL is nil, return JSON toot object at point."
	(if url
			(let* ((search (format "%s/api/v2/search" mastodon-instance-url))
						 (params `(("q" . ,url)
											 ("resolve" . "t"))) ; webfinger
						 (response (mastodon-http--get-json search params :silent)))
				(car (alist-get 'statuses response)))
		(mastodon-toot--base-toot-or-item-json)))

(defun my-mastodon-org-copy-toot-content (&optional url)
	"Copy the current toot's content as Org Mode.
Use pandoc to convert.

When called with \\[universal-argument], prompt for a URL."
	(interactive (list
								(when current-prefix-arg
									(read-string "URL: "))))

	(let ((toot (my-mastodon-toot-at-url url)))
		(with-temp-buffer
			(insert (alist-get 'content toot))
			(call-process-region nil nil "pandoc" t t nil "-f" "html" "-t" "org")
			(kill-new
			 (concat
				(org-link-make-string
				 (alist-get 'url toot)
				 (concat "@" (alist-get 'acct (alist-get 'account toot))))
				":\n\n#+begin_quote\n"
				(string-trim (buffer-string)) "\n#+end_quote\n"))
			(message "Copied."))))
#+end_src

